pub struct EnlargedAabb(/* private fields */);Expand description
An Axis-Aligned Bounding Box that contains the ColliderAabb with an additional margin.
This is used to avoid updating the Bounding Volume Hierarchy acceleration structure every time a collider moves only a small amount.
The enlarged AABB is updated automatically whenever the ColliderAabb
moves beyond the bounds of the current enlarged AABB.
Implementations
Sourceimpl EnlargedAabb
impl EnlargedAabb
Sourcepub fn new(aabb: ColliderAabb) -> Self
pub fn new(aabb: ColliderAabb) -> Self
Creates a new EnlargedAabb from the given ColliderAabb.
Sourcepub fn update(&mut self, aabb: &ColliderAabb, margin: Scalar) -> bool
pub fn update(&mut self, aabb: &ColliderAabb, margin: Scalar) -> bool
Updates the enlarged AABB with the given ColliderAabb and margin.
If the AABB is already contained within the enlarged AABB, nothing happens.
Returns true if the AABB was updated.
Sourcepub fn get(&self) -> ColliderAabb
pub fn get(&self) -> ColliderAabb
Gets the ColliderAabb of the enlarged AABB.
Methods from Deref<Target = ColliderAabb>
pub const INVALID: Self
Sourcepub fn grow(&self, amount: Vector) -> Self
pub fn grow(&self, amount: Vector) -> Self
Increases the size of the bounding volume in each direction by the given amount.
Sourcepub fn shrink(&self, amount: Vector) -> Self
pub fn shrink(&self, amount: Vector) -> Self
Decreases the size of the bounding volume in each direction by the given amount.
Sourcepub fn intersects(&self, other: &Self) -> bool
pub fn intersects(&self, other: &Self) -> bool
Checks if self intersects with other.